@@ -1,10 +1,18 @@
 #' Generate one statistic for all variables
 #'
+#' Use one stat function (made safe using statify) on all the data
+#' to produce a single statistics column.
+#'
+#' The result is either a numeric vector, or a character vector if
+#' the content of the column is not made entirely of numbers.
+#'
 #' @param stat The statistic to use
 #' @param data The dataframe to apply the statistic to
 #' @return A vector for one statistic column
-statColumn <- function(stat, data)
-{
+statColumn <- function(stat, data) {
+  # Apply one statified stat function to every variable in the data
+  # Return a simple vector for the column
+  # Statify checks types and output for the stat function. Returns a numeric vector or a character vector if needed.
   data %>%
     lapply(statify, stat) %>%
     unlist()
@@ -13,18 +21,25 @@ statColumn <- function(stat, data)
 
 #' Generate the table of all statistics for all variables
 #'
+#' If stats is a list of functions, use them.
+#' If it is a single function, use it with the entire data as
+#' its argument to produce a list of statistical functions to use.
+#'
 #' @param data The dataframe to apply the statistic to
 #' @param stats A list of named statistics to use
 #' @return A dataframe of all statistics for all variables
-statTable <- function(data, stats)
-{
-  # Call the stats arg_function passed, or use the provided list as-is
-  if (is.function(stats))
-    stats = stats(data)
+statTable <- function(data, stats) {
+  # If stats is a function, apply it to the data to obtain a list of stat functions
+  # Else use the function list as-is
+  if (is.function(stats)) stats = stats(data)
 
+  # Compute a statColumn for every stat function in stats
+  # Assemble the result in a dataframe
   stats %>%
     lapply(statColumn, data) %>%
-    data.frame(check.names = F, row.names = NULL, stringsAsFactors = F)
+    data.frame(check.names = F,
+               row.names = NULL,
+               stringsAsFactors = F)
 }
 
 
@@ -40,38 +55,38 @@ statTable <- function(data, stats)
 #' @param data The dataframe to get the names from
 #' @param labels The optional named character vector containing the keypairs var = "Label"
 #' @return A dataframe with one variable named "Variables", a character vector of variable names/labels and levels
-varColumn <- function(data, labels = NULL)
-{
-# Replace variable names by their labels, if they exist
-  names(data) -> base_names
+varColumn <- function(data, labels = NULL) {
+  # Every variable name that exists in the labels is to be replaced with its corresponding label
+  # Labels for non-existing variables are ignored
+  # Variables with no label are not replaced and used as-is
+  base_names <- names(data)
   base_names[base_names %in% names(labels)] <- labels[base_names[base_names %in% names(labels)]]
 
+  # Check if there are factors
+  data %>%
+    lapply(is.factor) %>%
+    unlist() -> factors
+
   # Insert levels for factors after the variable name
-  if (any(data %>% lapply(is.factor) %>% unlist()))
-  {
-    data %>%
-      lapply(is.factor) %>%
-      unlist() %>%
-      which() -> factors_idx
+  if (any(factors)) {
+    factors_idx <- which(factors)
 
+    # Factor names in **bold**
     base_names[factors_idx] <- paste0("**", base_names[factors_idx], "**")
-    factor_levels <-
-      factors_idx %>%
-      lapply(function(x)
-             {
-                paste0(base_names[x],
-                       ": ",
-                       "*",
-                       levels(data[[x]]),
-                       "*")
-             })
 
-    insert(x = base_names,
-           y = factor_levels,
-           position = factors_idx) -> base_names
+    # Factor levels in *italic*
+    factor_levels <- lapply(factors_idx, function(x) paste0(base_names[x], ": ", "*", levels(data[[x]]), "*"))
+
+    # Insert the factor levels after each factor name
+    base_names <- insert(x = base_names,
+                         y = factor_levels,
+                         position = factors_idx)
   }
 
-  data.frame(Variables = base_names, check.names = F, row.names = NULL, stringsAsFactors = F)
+  data.frame(Variables = base_names,
+             check.names = F,
+             row.names = NULL,
+             stringsAsFactors = F)
 }
 
 
@@ -151,35 +166,32 @@ varColumn <- function(data, labels = NULL)
 #' iris %>%
 #'   group_by(Petal.Length > 5) %>%
 #'   desctable(tests = list(.auto = tests_auto, Species = ~chisq.test))
-desctable <- function(data, stats, tests, labels)
-{
+desctable <- function(data, stats, tests, labels) {
   UseMethod("desctable", data)
 }
 
 
 #' @rdname desctable
 #' @export
-desctable.default <- function(data, stats = stats_auto, tests, labels = NULL)
-{
-  # Build the complete table
+desctable.default <- function(data, stats = stats_auto, tests, labels = NULL) {
+  # Assemble the Variables and the statTable in a single desctable object
   list(Variables = varColumn(data, labels),
-    stats = statTable(data, stats)) %>%
-  `class<-`("desctable")
+       stats = statTable(data, stats)) %>%
+  set_desctable_class()
 }
 
 
 #' @rdname desctable
 #' @export
-desctable.grouped_df <- function(data, stats = stats_auto, tests = tests_auto, labels = NULL)
-{
+desctable.grouped_df <- function(data, stats = stats_auto, tests = tests_auto, labels = NULL) {
   # Get groups then ungroup dataframe
-  grps <- data %>% dplyr::groups()
+  grps <- dplyr::groups(data)
   data <- dplyr::ungroup(data)
 
-  # Build the complete table recursively, assign "desctable" class
+  # Assemble the Variables (excluding the grouping ones) and the subTables recursively in a single desctable object
   c(Variables = list(varColumn(data[!names(data) %in% (grps %>% lapply(as.character) %>% unlist())], labels)),
     subTable(data, stats, tests, grps)) %>%
-  `class<-`("desctable")
+    set_desctable_class()
 }
 
 
@@ -191,8 +203,7 @@ desctable.grouped_df <- function(data, stats = stats_auto, tests = tests_auto, l
 #' @param grp Grouping factor
 #' @param df Dataframe containing the grouping factor
 #' @return A character vector with the names for the subtables
-subNames <- function(grp, df)
-{
+subNames <- function(grp, df) {
   paste0(as.character(grp),
          ": ",
          eval(grp, df) %>% factor() %>% levels(),
@@ -208,38 +219,35 @@ subNames <- function(grp, df)
 #' @param tests Test function or list of functions
 #' @param grp Grouping factor
 #' @return A numeric vector of pvalues
-testColumn <- function(df, tests, grp)
-{
+testColumn <- function(df, tests, grp) {
   group <- eval(grp, df)
 
-  df <- df %>%
-      dplyr::select(-!!(grp))
+  df <- df[!names(df) %in% as.character(grp)]
 
-  if (is.function(tests))
-  {
-    ftests <- df %>%
-      lapply(tests, group %>% factor())
+  # If tests is a function, apply it to the data and the grouping factor to produce a list of tests
+  # If there is an .auto element in the list of tests, apply the function as previously to select the relevant test
+  # If there is a .default element, use it as tests
+  # Else fall back on kruskal.test
+  if (is.function(tests)) {
+    ftests <- lapply(df, tests, factor(group))
     tests <- ftests
-  } else if (!is.null(tests$.auto))
-  {
-    ftests <- df %>%
-      lapply(tests$.auto, group %>% factor)
-  } else if (!is.null(tests$.default))
-  {
-    ftests <- df %>%
-      lapply(function(x){tests$.default})
-  } else
-  {
-    ftests <- df %>%
-      lapply(function(x){stats::kruskal.test})
-  }
+  } else if (!is.null(tests$.auto))  ftests <- lapply(df, tests$.auto, factor(group))
+  else if (!is.null(tests$.default)) ftests <- lapply(df, function(x){tests$.default})
+  else                               ftests <- lapply(df, function(x){stats::kruskal.test})
 
-  names(tests) %>% setdiff(".auto") %>% intersect(names(df)) -> forced_tests
+  # Select the forced (named) tests
+  tests %>%
+    names() %>%
+    setdiff(".auto") %>%
+    intersect(names(df)) -> forced_tests
+
+  # Assemble the complete list of tests to compute
   ftests[names(ftests) %in% forced_tests][forced_tests] <- tests[forced_tests]
 
+  # Compute the tests (made safe with testify) on the variable, using the grouping variable
   df %>%
     purrr::map2(ftests, testify, group) %>%
-    dplyr::bind_rows()
+    Reduce(f = rbind)
 }
 
 
@@ -250,32 +258,26 @@ testColumn <- function(df, tests, grp)
 #' @param tests Tests list/function to use
 #' @param grps List of symbols for grouping factors
 #' @return A nested list of statTables and testColumns
-subTable <- function(df, stats, tests, grps)
-{
-  # Final group, make tests
-  if (length(grps) == 1)
-  {
-    group <- eval(grps[[1]], df) %>% factor()
+subTable <- function(df, stats, tests, grps) {
+  # Final group, compute tests
+  if (length(grps) == 1) {
+    group <- factor(eval(grps[[1]], df))
 
     # Create the subtable stats
-    df %>%
-      dplyr::select(-!!(grps[[1]])) %>%
+    df[!names(df) %in% as.character(grps[[1]])] %>%
       by(group, statTable, stats) %>%
       # Name the subtables with info about group and group size
       stats::setNames(subNames(grps[[1]], df)) -> stats
 
     # Create the subtable tests
-    testColumn(df, tests, grps[[1]]) -> pvalues
+    pvalues <- testColumn(df, tests, grps[[1]])
 
     c(stats, tests = list(pvalues))
-  }
-  else
-  {
+  } else {
     group <- eval(grps[[1]], df)
 
     # Go through the next grouping levels and build the subtables
-    df %>%
-      dplyr::select(-!!(grps[[1]])) %>%
+    df[!names(df) %in% as.character(grps[[1]])] %>%
       by(group, subTable, stats, tests, grps[-1]) %>%
       # Name the subtables with info about group and group size
       stats::setNames(subNames(grps[[1]], df))
