@@ -7,3 +7,5 @@ dplyr::`%>%`
 #' @export
 dplyr::group_by
 
+#' @importFrom pander pander
+pander::pander
